pub enum GapPolicy {
Skip,
InsertZeros,
}Expand description
The policy to apply when gaps are found in the data.
Variants
Skip
Treats missing data as if the bucket does not exist. It will skip the bucket and continue calculating using the next available value.
InsertZeros
Replaces missing values with a zero (0) and pipeline aggregation
computation will proceed as normal.